@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from cow.server import Server
+from cow.plugins.motor_plugin import MotorPlugin
 
 from tests.sandbox.handlers.test import TestHandler
 
@@ -12,5 +13,10 @@ class SandboxServer(Server):
             ('/', TestHandler),
         )
 
+    def get_plugins(self):
+        return [
+            MotorPlugin
+        ]
+
 if __name__ == '__main__':
     SandboxServer.run()
